@@ -6,7 +6,7 @@
 --------------------------------------------------------------------------------
 {- |
 Module      :  Script
-Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014 Douglas Burke
+Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012, 2014, 2018 Douglas Burke
 License     :  GPL V2
 
 Maintainer  :  Douglas Burke
@@ -132,6 +132,10 @@ import Control.Monad.State (modify, gets, lift)
 import Data.Monoid (Monoid(..))
 #endif
 
+#if MIN_VERSION_base(4, 7, 0)
+import Data.Functor (($>))
+#endif
+
 import Network.URI (URI(..))
 
 import qualified Control.Exception as CE
@@ -142,6 +146,11 @@ import qualified Data.Text.Lazy.Builder as B
 import qualified Data.Text.Lazy.IO as LIO
 import qualified System.IO.Error as IO
 
+#if !MIN_VERSION_base(4, 7, 0)
+($>) :: Functor f => f a -> b -> f b
+($>) = flip (<$)
+#endif
+
 ------------------------------------------------------------
 --
 --  The parser used to be based on the Notation3 parser, and used many
@@ -356,7 +365,7 @@ bwdChain =
 -- TODO: is the loss of identLetter a problem?
 commandName :: String -> N3Parser ()
 -- commandName cmd = try (string cmd *> notFollowedBy identLetter *> whiteSpace)
-commandName cmd = symbol cmd *> pure ()
+commandName cmd = symbol cmd $> ()
 
 restOfLine :: N3Parser String
 restOfLine = manyTill (satisfy (const True)) eoln <* whiteSpace
@@ -379,9 +388,7 @@ graphExpr :: N3Parser (SwishStateIO (Either String RDFGraph))
 graphExpr =
         graphOnly
     <|>
-        do  { f <- formulaExpr
-            ; return $ liftM (liftM formExpr) f
-            }
+        fmap (fmap formExpr) <$> formulaExpr
 
 graphOnly :: N3Parser (SwishStateIO (Either String RDFGraph))
 graphOnly =
@@ -452,7 +459,7 @@ ssAddReturnFormula ::
 ssAddReturnFormula nam gf =
         do  { egr <- gf
             ; ssAddGraph nam [return egr]
-            ; return $ liftM (Formula nam) egr
+            ; return $ fmap (Formula nam) egr
             }
 
 ssAddGraph ::
@@ -470,7 +477,7 @@ ssAddGraph nam gf =
             }
 
 ssGetGraph :: ScopedName -> SwishStateIO (Either String RDFGraph)
-ssGetGraph nam = liftM head <$> ssGetList nam
+ssGetGraph nam = fmap head <$> ssGetList nam
   
 ssGetFormula :: ScopedName -> SwishStateIO (Either String RDFFormula)
 ssGetFormula nam = gets find
@@ -880,10 +887,7 @@ getResourceData muri =
         Nothing  -> fromStdin
         Just uri -> fromUri uri
     where
-    fromStdin =
-        do  { dat <- lift LIO.getContents
-            ; return $ Right dat
-            }
+    fromStdin = Right <$> lift LIO.getContents
     fromUri = fromFile
     fromFile uri | uriScheme uri == "file:" = Right `fmap` lift (LIO.readFile $ uriPath uri)
                  | otherwise = error $ "Unsupported file name for read: " ++ show uri
@@ -1482,7 +1486,7 @@ and the output is
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012 Douglas Burke  
+--    2011, 2012, 2014, 2018 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
